@@ -96,7 +96,7 @@ char *aliaslist[] =
 	"char-major-10-139 openprom",	/* /dev/openprom Linux/Sparc interface */
 	"char-major-10-144 nvram", /* from Tigran Aivazian <tigran@sco.COM> */
 	 
-	"char-major-14 sound",
+	"char-major-14 soundcore",
 	"char-major-19 cyclades",
 	"char-major-20 cyclades",
 	"char-major-21 sg",
@@ -148,7 +148,7 @@ char *aliaslist[] =
 	"tty-ldisc-3 ppp",
 	"ppp-compress-21 bsd_comp",
 	"ppp-compress-24 ppp_deflate",
-	"ppp-compress-24 ppp_deflate",
+	"ppp-compress-26 ppp_deflate",
 
 	"parport_lowlevel parport_pc",
 
