@@ -616,7 +616,8 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
 						old_name, ETC_MODULES_CONF, old_name, ETC_MODULES_CONF,
 						ETC_MODULES_CONF,
 						old_name, ETC_MODULES_CONF);
-				else
+				else {
+#ifndef NO_WARN_ON_OLD_LINK
 					fprintf(stderr,
 						"Warning: You do not need a link from %s to\n"
 						"         %s.  The use of %s is depreciated,\n"
@@ -625,7 +626,9 @@ static int do_read(int all, char *force_ver, char *base_dir, char *conf_file)
 						old_name, ETC_MODULES_CONF,
 						old_name, old_name,
 						old_name);
+#endif
 				}
+			}
 			else
 				fprintf(stderr,
 					"Warning: modutils is reading from %s and\n"
